STATE_MAIN_METRIC = "loss"

# stages
STAGE_INFER_PREFIX = "infer"

# loader
LOADER_TRAIN_PREFIX = "train"
LOADER_VALID_PREFIX = "valid"
LOADER_INFER_PREFIX = "infer"

# callbacks
